import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;
/**
 * transform mock data
 * {
 *  0: '华东分部',
 * '0-0': '华东分部-研发部'
 * '0-1': '华东分部-市场部',
 *  ...
 * }
 */
export const deptMap = (() => {
  const pDept = ['华东分部', '华南分部', '西北分部'];
  const cDept = ['研发部', '市场部', '商务部', '财务部'];

  return pDept.reduce((map, p, pIdx) => {
    map[pIdx] = p;

    cDept.forEach((c, cIndex) => (map[`${pIdx}-${cIndex}`] = `${p}-${c}`));

    return map;
  }, {});
})();

export const columns: BasicColumn[] = [
  {
    title: '工作区名称',
    dataIndex: 'workSpaceName',
    width: 120,
  },
  {
    title: '创建人',
    dataIndex: 'createBy',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 140,
  },
];

export const groupUserColumns: BasicColumn[] = [
  {
    title: '姓名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '账号',
    dataIndex: 'username',
    width: 120,
  },
  {
    title: '所属工作组',
    dataIndex: 'groupName',
    width: 140,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'username',
    label: '账号',
    component: 'Input',
    colProps: { span: 8 },
  },
];
export const formSchema: FormSchema[] = [
  {
    field: 'workSpaceName',
    label: '工作区名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'createBy',
    label: '管理员',
    component: 'Input',
    required: true,
  },
];

export const searchDetailFormSchema: FormSchema[] = [
  {
    field: 'username',
    label: '角色名称',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const groupColumns: BasicColumn[] = [
  {
    title: '姓名',
    dataIndex: 'name',
    width: 200,
  },
  {
    title: '账号',
    dataIndex: 'username',
    width: 200,
  },
  {
    title: '部门',
    dataIndex: 'deptId',
    width: 200,
  },
  {
    title: '角色',
    dataIndex: 'roleNames',
    width: 200,
  },
];
export const approvalColumns: BasicColumn[] = [
  {
    title: '模块',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '申请类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '需要审批',
    dataIndex: 'flag',
    width: 50,
    customRender: ({ record }) => {
      return h(Switch, {
        checked: record.flag === '1',
        onChange(checked: CheckedType) {
          const newStatus = checked ? '1' : '0';
          const { createMessage } = useMessage();
          record.flag = newStatus;
          const text = record.flag === '1' ? '启用' : '停用';
          createMessage.success(text + `成功`);
        },
      });
    },
  },
  {
    title: '流程发布状态',
    dataIndex: 'streamType',
    width: 120,
  },
];
export const approvalSearchFormSchema: FormSchema[] = [
  {
    field: 'type',
    label: '申请类型',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '新增', value: '1' },
        { label: '修改', value: '2' },
      ],
    },
  },
  {
    field: 'flag',
    label: '是否需要审批',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '是', value: '1' },
        { label: '否', value: '2' },
      ],
    },
  },
];

export const accountFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'admin', value: 'admin' },
        { label: '工作组管理员', value: '工作组管理员' },
        { label: 'sdad', value: 'sdad' },
        { label: '测试用户', value: '测试用户' },
        { label: 'cscs1', value: 'cscs1' },
        { label: 'scasca', value: 'scasca' },
      ],
    },
    label: '添加用户',
    required: true,
  },
  {
    field: 'groupName',
    component: 'Select',
    componentProps: {
      options: [
        { label: '监察工作组', value: '监察工作组' },
        { label: '检查工作组', value: '检查工作组' },
        { label: '财务工作组', value: '财务工作组' },
        { label: '市场工作组', value: '市场工作组' },
        { label: '商城工作组', value: '商城工作组' },
        { label: '测试工作组', value: '测试工作组' },
      ],
    },
    label: '所属工作组',
    required: true,
  },
];

export const groupFormSchema: FormSchema[] = [
  {
    field: 'groupName',
    component: 'Input',
    label: '工作组名称',
    required: true,
  },
  {
    field: 'workspaceName',
    component: 'Select',
    componentProps: {
      options: [
        { label: '监察工作区', value: '监察工作区' },
        { label: '检查工作区', value: '检查工作区' },
        { label: '财务工作区', value: '财务工作区' },
        { label: '市场工作区', value: '市场工作区' },
        { label: '商城工作区', value: '商城工作区' },
        { label: '测试工作区', value: '测试工作区' },
      ],
    },
    label: '所属工作区',
    required: true,
  },
];
